@@ -150,7 +150,7 @@ def configure_command(
     # Switch to new CI conf.
     ensure_new_ci_conf(fetcher_project, ctx)
     ensure_pipeline_schedule(fetcher_project, ctx)
-    ensure_ssh_key_pair(fetcher_project, source_data_project, json_data_project, ctx)
+    ensure_ssh_key_pairs(fetcher_project, source_data_project, json_data_project, ctx)
     ensure_json_data_webhooks(json_data_project, ctx)
 
 
@@ -183,7 +183,14 @@ def find_variable_by_name(project: Project, name: str) -> Optional[str]:
         return None
 
 
-def find_deploy_key_by_title(project: Project, title: str) -> Optional[DeployKey]:
+def find_deploy_key_by_title(ctx: Context, title: str) -> Optional[DeployKey]:
+    for key in ctx.gl.deploykeys.list(as_list=False):
+        if key.title == title:
+            return key
+    return None
+
+
+def find_project_deploy_key_by_title(project: Project, title: str) -> Optional[DeployKey]:
     for key in project.keys.list(as_list=False):
         if key.title == title:
             return key
@@ -215,18 +222,18 @@ def delete_deploy_keys(project: Project, ctx: Context):
         logger.info("No deploy key found for %r", project)
 
 
-def ensure_ssh_key_pair(
+def ensure_ssh_key_pairs(
     fetcher_project: Project, source_data_project: Project, json_data_project: Project, ctx: Context,
 ):
-    """Checks that the SSH key pair is configured, otherwise configure a new one.
+    """Checks that the SSH key pairs are configured, otherwise configure them.
 
     In particular ensure that the fetcher project has a SSH_PRIVATE_KEY masked variable,
     and that source-data and json-data projects have a deploy key.
     """
     ssh_private_key_variable = find_variable_by_name(fetcher_project, SSH_PRIVATE_KEY)
     deploy_key_title = get_deploy_key_title(ctx)
-    source_data_deploy_key = find_deploy_key_by_title(source_data_project, deploy_key_title)
-    json_data_deploy_key = find_deploy_key_by_title(json_data_project, deploy_key_title)
+    source_data_deploy_key = find_project_deploy_key_by_title(source_data_project, deploy_key_title)
+    json_data_deploy_key = find_project_deploy_key_by_title(json_data_project, deploy_key_title)
     if not ssh_private_key_variable or not source_data_deploy_key or not json_data_deploy_key:
         # Do some cleanup.
         delete_env_variable(fetcher_project, SSH_PRIVATE_KEY, ctx)
@@ -251,6 +258,22 @@ def ensure_ssh_key_pair(
     else:
         logger.info("SSH key pair is already configured for this fetcher")
 
+    deploy_key_title = "next.db.nomics.world fetchers"
+    source_data_deploy_key = find_project_deploy_key_by_title(source_data_project, deploy_key_title)
+    json_data_deploy_key = find_project_deploy_key_by_title(json_data_project, deploy_key_title)
+    if not source_data_deploy_key or not json_data_deploy_key:
+        # Add deploy key for fetchers running in Kubernetes cluster "next.db.nomics.world".
+        deploy_key = find_deploy_key_by_title(ctx, deploy_key_title)
+        if not ctx.dry_run and deploy_key:
+            source_data_project.keys.enable(deploy_key.id)
+            source_data_project.keys.update(deploy_key.id, {"can_push": True})
+            logger.info("%r enabled for %r", deploy_key, source_data_project)
+            json_data_project.keys.enable(deploy_key.id)
+            json_data_project.keys.update(deploy_key.id, {"can_push": True})
+            logger.info("%r enabled for %r", deploy_key, json_data_project)
+    else:
+        logger.info("SSH key pair for next.db.nomics.world is already configured for this fetcher")
+
 
 def ensure_new_ci_conf(project: Project, ctx: Context):
     def is_shared_pipeline(include) -> bool:
